# Contributing to Astral.js

Thank you for considering contributing to Astral.js! We welcome any contributions that help improve the library and make it even better. By contributing, you can help us fix bugs, add new features, enhance documentation, and more.

To ensure a smooth collaboration and maintain a high-quality codebase, please follow the guidelines below when contributing to the project.

## Table of Contents

- [Getting Started](#getting-started)
    - [Installation](#installation)
    - [Development Setup](#development-setup)
- [Contributing Guidelines](#contributing-guidelines)
    - [Bug Reports](#bug-reports)
    - [Feature Requests](#feature-requests)
- [Code Style](#code-style)
- [License](#license)

## Getting Started

### Installation

Before you start contributing to Astral.js, make sure you have it installed. You can install it using npm:

```bash
npm install astral.js
```

### Development Setup

To set up the development environment, follow these steps:To set up the development environment and start contributing, follow these steps:

1. Clone the Astral.js repository to your local machine:

    ```bash
    git clone https://github.com/rabisnaqvi/Astral.js.git
    ```
2. Navigate to the project directory:
    
    ```bash
    cd Astral.js
    ```
3. Install the dependencies:

    ```bash
    npm install
    ```
4. Create a new branch for your changes:
    
    ```bash
    git checkout -b my-branch-name
    ```
5. Make your desired changes and ensure that the code passes all tests.
6. Commit your changes with a descriptive commit message:  
    ```bash
    git commit -m "Add feature X"
    ```
7. Push your changes to the remote repository:
    ```bash
    git push origin my-branch-name
    ```
8. Go to the Astral.js repository on GitHub and create a new pull request from your branch.
9. Provide a clear title and description for your pull request, explaining the purpose of the changes.
10. Wait for the pull request to be reviewed and merged.
11. Celebrate! 🎉


## Contributing Guidelines

### Bug Reports

If you encounter a bug while using Astral.js, please [open an issue](https://github.com/rabisnaqvi/Astral.js/issues). Before opening an issue, please check if a similar issue already exists. If it does, you can add a comment to the existing issue instead of opening a new one.

When opening a new issue, please provide as much information as possible. Include the following details:

- Provide a descriptive title for the issue.
- Clearly describe the problem, including steps to reproduce it.
- If possible, include any relevant code examples or screenshots.

Submit the issue, and we'll review it as soon as possible.

### Feature Requests

If you have a suggestion for a new feature or improvement in Astral.js, we'd love to hear it. To submit a feature request, follow these steps:

1. [Open an issue](https://github.com/rabisnaqvi/Astral.js/issues/new/choose) and select the "Feature Request" template.
2. Provide a descriptive title for the feature request.
3. Clearly describe the feature you'd like to see added.
4. If applicable, include any supporting information such as code snippets, diagrams, or examples.
5. Submit the issue, and we'll review it as soon as possible.

## Code Style

To maintain a consistent code style throughout the project, we use ESLint and Prettier. Before submitting a pull request, please ensure that your code adheres to the linting rules and passes all tests. You can run the following command to check your code:

```bash
npm run lint
npm run format
```

## License

Astral.js is licensed under the [MIT License](https://github.com/rabisnaqvi/Astral.js/blob/main/LICENSE.md). By contributing to the project, you agree to license your contributions under the same license.


---

We appreciate your interest in contributing to Astral.js. Your contributions are valuable and will help make the library more robust and feature-rich. If you have any questions, feel free to reach out to us.

Happy coding!

The Astral.js Team