# ![Astral Icon](https://github.com/rabisnaqvi/Astral.js/blob/main/assets/astral-icon.png) Astral.js

[![License](https://img.shields.io/badge/license-MIT-blue.svg)](LICENSE.md)
[![npm](https://img.shields.io/npm/v/astral.js.svg)](https://www.npmjs.com/package/astral.js)
[![Coverage Status](https://coveralls.io/repos/github/rabisnaqvi/Astral.js/badge.svg?branch=main)](https://coveralls.io/github/rabisnaqvi/Astral.js?branch=main)

Astral.js is a lightweight UI toolkit designed to empower JavaScript developers with powerful tools for building modern user interfaces. With Astral.js, you gain access to a comprehensive set of features including context and state management, event-driven architecture, and sophisticated JavaScript-powered media queries.

## Features

- **State Management**: Astral.js allows developers to create and manage separate state storage for their applications. It provides a clean and encapsulated way to store and update data, making it easy to track and manage application state.
- **Event-Driven Architecture**: The library offers a built-in event system that allows components to communicate and react to changes in state. Developers can subscribe to specific events and define custom callbacks to perform actions whenever those events are published.
- **Media Queries**: The library provides a powerful media query system that allows developers to define custom breakpoints and query the current viewport size. It also provides a built-in set of breakpoints for common device sizes. With straight-forward API, that handle both successfull and failed query matches, developers can easily create responsive UIs that adapt to different screen sizes.
- **Lightweight**: Astral.js is designed to be lightweight and performant, with a small build size of less than 5kb. It minimizes the impact on application performance and ensures a smooth user experience.
- **Customizable**: Astral.js is designed to be highly customizable and extensible. It provides a flexible API that allows developers to easily add new features and customize existing ones.
- **Cross-Browser Compatibility**: The library is designed to work across all modern browsers, including Chrome, Firefox, Safari, and Edge.
- **Easy Integration**: The library can be easily integrated into new or existing projects. It supports both direct script imports and ES6 module imports, allowing developers to choose the integration method that best suits their needs.
- **Developer-Friendly API**: Astral.js provides a simple and intuitive API that is easy to understand and work with. It offers methods for getting and updating state, setting debug mode, and subscribing to state change events, making it developer-friendly and accessible.
- **Testability**: The library is designed with testability in mind, making it easy to write unit tests for components that use Astral.js for state management. Its modular and encapsulated approach facilitates isolated testing of individual components.
- **Documentation and Examples**: Astral.js includes comprehensive documentation that explains its usage and API. It also provides examples and code snippets to help developers quickly grasp the concepts and integrate the library into their projects.
- **MIT License**: Astral.js is released under the permissive MIT License, allowing developers to freely use, modify, and distribute the library in both personal and commercial projects

## Getting Started

To get started with Astral.js, refer to the [Installation](#installation) section in the README.md file, which provides step-by-step instructions for integrating the library into your project. The documentation also covers usage examples and API details to help you leverage the full power of Astral.js in your applications.

## Installation

You can install the library using npm:

```shell
npm install astral.js --save
```

## Contributing

Astral.js is an open-source project, and contributions are welcome! If you encounter any issues, have suggestions for improvements, or would like to contribute code, please follow the guidelines outlined in the CONTRIBUTING.md file.

## License

Astral.js is released under the MIT License. See LICENSE.md for more information.

## Credits

Astral.js is developed and maintained by [Rabis Naqvi](https://linktr.ee/rabisnaqvi) and contributors. We would like to acknowledge the contributions of the open-source community and express our gratitude to all the developers who have helped make this project better.